"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createPersistanceMiddleware = createPersistanceMiddleware;
var _slice = require("@theme/ApiDemoPanel/Authorization/slice");
var _storageUtils = require("./storage-utils");
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */

function createPersistanceMiddleware(options, siteTitle = "") {
  const persistanceMiddleware = storeAPI => next => action => {
    const result = next(action);
    const state = storeAPI.getState();
    const storage = (0, _storageUtils.createStorage)("sessionStorage");
    if (action.type === _slice.setAuthData.type) {
      for (const [key, value] of Object.entries(state.auth.data)) {
        if (Object.values(value).filter(Boolean).length > 0) {
          storage.setItem(key, JSON.stringify(value));
        } else {
          storage.removeItem(key);
        }
      }
    }
    if (action.type === _slice.setSelectedAuth.type) {
      if (state.auth.selected) {
        storage.setItem((0, _storageUtils.hashArray)(Object.keys(state.auth.options)), state.auth.selected);
      }
    }

    // TODO: determine way to rehydrate without flashing
    // if (action.type === "contentType/setContentType") {
    //   storage.setItem("contentType", action.payload);
    // }

    // if (action.type === "accept/setAccept") {
    //   storage.setItem("accept", action.payload);
    // }

    if (action.type === "server/setServer") {
      storage.setItem(`${siteTitle}-server`, action.payload);
    }
    if (action.type === "server/setServerVariable") {
      var _storage$getItem;
      const server = (_storage$getItem = storage.getItem(`${siteTitle}-server`)) !== null && _storage$getItem !== void 0 ? _storage$getItem : "{}";
      const variables = JSON.parse(action.payload);
      let serverObject = JSON.parse(server);
      serverObject.variables[variables.key].default = variables.value;
      storage.setItem(`${siteTitle}-server`, JSON.stringify(serverObject));
    }
    return result;
  };
  return persistanceMiddleware;
}